@@ -19,12 +19,8 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 print """M30W Copyright (C) 2012 M30W developers.
 """
-from core.debug import debug
-from core.GUI import show_app
+from M30W.debug import debug
+from M30W.GUI import show_app
 
-def main():
-    debug("Starting GUI...", 1)
-    show_app()
-
-if __name__ == '__main__':
-    main()
\ No newline at end of file
+debug("Starting GUI...", 1)
+show_app()
